@@ -4,17 +4,29 @@
 import os
 import sys
 
-from pyfygentlescrap.yahoo.yahoo_screener import yahoo_equity_screener
+from pyfygentlescrap.warnings import (  # noqa F401
+    InvalidParameterWarning,
+    InvalidRegionWarning,
+    InvalidResponseWarning,
+    MarketOpenWarning,
+    NoInternetWarning,
+    WrongTypeWarning,
+)
+from pyfygentlescrap.yahoo.yahoo_screener import (
+    nb_equities_available,
+    yahoo_equity_screener,
+)
 from pyfygentlescrap.yahoo.yahoo_historical import yahoo_historical_data
 from pyfygentlescrap.yahoo.yahoo_shared import yahoo_session
 from pyfygentlescrap.yahoo.yahoo_ticker import yahoo_ticker
 
 
-__version__ = "0.3.0"
+__version__ = "0.4.0"
 
 
 sys.path.insert(0, os.path.abspath(".."))
 __all__ = [
+    "nb_equities_available",
     "yahoo_equity_screener",
     "yahoo_historical_data",
     "yahoo_session",
